<?php
/*
  $Id: cm_header_reviews.php
  $Loc: catalog/includes/modules/content/header/

  CE Phoenix, E-Commerce made Easy
  https://phoenixcart.org

  Header Modules 3.2 Phoenix
  by @raiwa
  info@oscaddons.com
  www.oscaddons.com

  Copyright (c) 2021 Rainer Schmied

  Released under the GNU General Public License
*/

  class cm_header_reviews extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_HEADER_REVIEWS_';

    public function __construct() {
      parent::__construct(__FILE__);
    }

    public function execute() {

      $content_width = (int)MODULE_CONTENT_HEADER_REVIEWS_CONTENT_WIDTH;

      $allow_reviews = true;

      if ( ALLOW_ALL_REVIEWS == 'false' && isset($_SESSION['customer_id']) ) {
        $purchased = [];
        $purchased_products_array = $GLOBALS['db']->query(sprintf(<<<'EOSQL'
SELECT DISTINCT op.products_id 
  FROM orders o, orders_products op 
  WHERE o.customers_id = %s 
    AND o.orders_id = op.orders_id 
  GROUP BY products_id
EOSQL
          , (int)$_SESSION['customer_id']));

        while ($purchased_products = $purchased_products_array->fetch_assoc()) {
          $purchased[] = $purchased_products['products_id'];
        }
        if ( !isset($_GET['products_id']) || !in_array((int)$_GET['products_id'], $purchased) ) $allow_reviews = false;
      }

      $random_select = sprintf(<<<'EOSQL'
SELECT r.reviews_id, r.products_id, r.reviews_rating, substring(rd.reviews_text, 1, %1$s) AS reviews_text, p.products_id, p.products_image, pd.products_name 
  FROM reviews r, reviews_description rd, products p, products_description pd 
  WHERE p.products_status = '1' 
    AND p.products_id = r.products_id 
    AND r.reviews_id = rd.reviews_id 
    AND rd.languages_id = %2$s 
    AND p.products_id = pd.products_id 
    AND pd.language_id = %2$s 
    AND r.reviews_status = 1
EOSQL
          , MODULE_CONTENT_HEADER_REVIEWS_LENGTH, (int)$_SESSION['languages_id']);

      if ( MODULE_CONTENT_HEADER_REVIEWS_PRODUCT_FILTER == 'True' && isset($_GET['products_id'])) {
        $random_select .= sprintf(<<<'EOSQL'
  AND p.products_id = %s
EOSQL
          , (int)$_GET['products_id']);
      }
      $random_select .= sprintf(<<<'EOSQL'
  ORDER BY rand() LIMIT %s
EOSQL
          , (int)MODULE_CONTENT_HEADER_REVIEWS_CONTENT_LIMIT);

      $random_query = $GLOBALS['db']->query($random_select);
      $num_reviews = mysqli_num_rows($random_query);

      $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
      include 'includes/modules/content/cm_template.php';
    }

    public function get_parameters() {
      return [
        static::CONFIG_KEY_BASE . 'VERSION' => [
          'title' => 'Current Version',
          'value' => '3.2 Phoenix',
          'desc' => 'Version info. It is read only.',
          'set_func' => 'cm_header_reviews::readonly(',
        ],
        static::CONFIG_KEY_BASE . 'STATUS' => [
          'title' => 'Enable Reviews Header Module',
          'value' => 'True',
          'desc' => 'Do you want to add the module to your Header?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        static::CONFIG_KEY_BASE . 'ALIGN' => [
          'title' => 'Dropdown align',
          'value' => 'Left',
          'desc' => 'How should the dropdown menu content be aligned relative to the menu button.',
          'set_func' => "Config::select_one(['Left', 'Right'], ",
        ],
        static::CONFIG_KEY_BASE . 'CONTENT_WIDTH' => [
          'title' => 'Content Width',
          'value' => '3',
          'desc' => 'What width container should the content be shown in?',
          'set_func' => "Config::select_one(['12', '11', '10', '9', '8', '7', '6', '5', '4', '3', '2', '1'], ",
        ],
        static::CONFIG_KEY_BASE . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '0',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        static::CONFIG_KEY_BASE . 'CONTENT_LIMIT' => [
          'title' => 'Number of Products',
          'value' => '6',
          'desc' => 'How many Best Sellers should be shown in the drop down menu? Zero disables the menu.',
        ],
        static::CONFIG_KEY_BASE . 'LENGTH' => [
          'title' => 'Text length',
          'value' => '35',
          'desc' => 'Length of the review text (characters).',
        ],
        static::CONFIG_KEY_BASE . 'PRODUCT_FILTER' => [
          'title' => 'Product filter',
          'value' => 'True',
          'desc' => 'Do you want to show only reviews for the actual product if on the product page?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        static::CONFIG_KEY_BASE . 'IMAGE' => [
          'title' => 'Show images',
          'value' => 'True',
          'desc' => 'Do you want to show the product images?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
      ];
    }

    public static function readonly($value) {
      return $value;
    }

  }
